Crate heatshrink

Crate heatshrink 

Minimal compression & decompression library for embedded use Implements the Heatshrink compression algorithm described here https://github.com/atomicobject/heatshrink and here https://spin.atomicobject.com/2013/03/14/heatshrink-embedded-data-compression/

Structs

Config
Structure holding the configuration parameters These can be tuned to improve compression ratio But they must be the same for encode() & decode() calls to be able to produce the original data

Enums

DecodeError
Errors that can be encountered while decompressing data
EncodeError
Errors that may be encountered when compressing data

Functions

decode
Basic decompression call. Source and destination must reside in memory, and destination must be large enough to hold the decompressed data, or an error will be returned
encode
Basic compression call. Source and destination must reside in memory, and destination must be large enough to hold the compressed data, or an error will be returned