pub enum Poll {
More(usize),
Empty(usize),
}Expand description
Outcome of a successful encoder::HeatshrinkEncoder::poll or
decoder::HeatshrinkDecoder::poll call.
Variants
More(usize)
Output buffer is full; more compressed/decompressed data is available. Value is the number of bytes written into the output buffer.
Empty(usize)
Internal state is fully drained for now. Value is the number of bytes written into the output buffer.
Implementations